
/* Ensures new hotfix field in settings */
DECLARE @settingid int
SET @settingid = ISNULL((SELECT Top 1 KeyID FROM CMS_SettingsKey WHERE KeyName = N'CMSHotfixVersion'), 0)

IF (@settingid = 0) BEGIN

INSERT INTO [CMS_SettingsKey]
           ([KeyName]
           ,[KeyDisplayName]
           ,[KeyDescription]
           ,[KeyValue]
           ,[KeyType]
           ,[KeyCategoryID]
           ,[SiteID]
           ,[KeyGUID]
           ,[KeyLastModified]
           ,[KeyOrder]
           ,[KeyDefaultValue]
           ,[KeyValidation]
           ,[KeyEditingControlPath]
           ,[KeyLoadGeneration]
           ,[KeyIsGlobal])
     VALUES
           ('CMSHotfixVersion'
           ,'Hotfix version'
           ,'Hotfix version'
           ,'0'
           ,'int'
           ,NULL
           ,NULL
           ,newId()
           ,getDate()
           ,NULL
           ,'0'
           ,NULL
           ,NULL
           ,0
           ,1)
END
GO

-- Inserting Resource strings
DECLARE @stringId AS int;
DECLARE @cultureId AS int;
DECLARE @cultureCode AS nvarchar(50);

-- Change value of this parameter if your default UI culture is not 'en-US' (see details in hotfix instructions)
SET @cultureCode = 'en-US';

-- Get culture ID
SET @cultureID = (SELECT UICultureID FROM [CMS_UICulture] WHERE UICultureCode=@cultureCode);

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'accessdenied.notallowedtocreatenewcultureversion' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('accessdenied.notallowedtocreatenewcultureversion'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'You''re not allowed to create a new culture version.')
END

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'cssstylesheet.notallowedtoedit' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('cssstylesheet.notallowedtoedit'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'You aren''t allowed to modify selected stylesheet.')
END

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'cssstylesheet.errorediting' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('cssstylesheet.errorediting'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Error editing CSS stylesheet')
END


-- Check if resource string general.badhashtex exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'SelectColumns.nocustomtablesavaible' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('SelectColumns.nocustomtablesavaible'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'No custom table avaible.')
END

-- Check if resource string general.badhashtex exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'definesitestructure.insertfailed' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('definesitestructure.insertfailed'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Failed to insert document')
END
GO


-- Update deleting role dependencies
ALTER PROCEDURE [Proc_CMS_Role_RemoveDependences]
    @RoleID int
AS
BEGIN
    -- SET NOCOUNT ON added to prevent extra result sets from
    -- interfering with SELECT statements.
    SET NOCOUNT ON;
    
    BEGIN TRANSACTION;
    
    DELETE FROM CMS_UserRole WHERE RoleID=@RoleID;
    DELETE FROM CMS_RolePermission WHERE RoleID=@RoleID; 
    DELETE FROM CMS_ACLItem WHERE RoleID=@RoleID;
    DELETE FROM CMS_WorkflowStepRoles WHERE RoleID=@RoleID; 
    DELETE FROM Forums_ForumRoles WHERE RoleID = @RoleID;
    DELETE FROM Polls_PollRoles WHERE RoleID = @RoleID;
    DELETE FROM Media_LibraryRolePermission WHERE RoleID = @RoleID;
    DELETE FROM Community_GroupRolePermission WHERE RoleID = @RoleID;
    DELETE FROM CMS_WidgetRole WHERE RoleID = @RoleID;
    -- Message boards
    DELETE FROM Board_Role WHERE RoleID = @RoleID;
    -- UIProfiles
    DELETE FROM CMS_RoleUIElement WHERE RoleID = @RoleID;
    --Newsletters
    DELETE FROM [Newsletter_SubscriberNewsletter] WHERE [SubscriberID] IN (SELECT SubscriberID FROM Newsletter_Subscriber WHERE SubscriberType LIKE 'cms.role' AND SubscriberRelatedID = @RoleID);
    DELETE FROM [Newsletter_Emails] WHERE EmailSubscriberID IN (SELECT SubscriberID FROM Newsletter_Subscriber WHERE SubscriberType LIKE 'cms.role' AND SubscriberRelatedID = @RoleID);
    DELETE FROM [Newsletter_Subscriber] WHERE SubscriberType LIKE 'cms.role' AND SubscriberRelatedID = @RoleID;
     -- Project Management
	DELETE FROM [PM_ProjectRolePermission] WHERE RoleID = @RoleID;    
    
    COMMIT TRANSACTION;
END
GO


-- Update deleting user dependencies
ALTER PROCEDURE [Proc_CMS_User_RemoveDependences]
    @ID int
AS
BEGIN
    -- SET NOCOUNT ON added to prevent extra result sets from
    -- interfering with SELECT statements.
    SET NOCOUNT ON;
    BEGIN TRANSACTION;
    -- deletes dependencies in CMS_UserSite, CMS_UserRole and CMS_EmailUser
    DELETE FROM [CMS_UserSite] WHERE UserID=@ID;
    DELETE FROM [CMS_UserRole] WHERE UserID=@ID;
    DELETE FROM [CMS_EmailUser] WHERE UserID=@ID;
    -- delete dependencies in CMS_UserCulture
    DELETE FROM [CMS_UserCulture] WHERE UserID=@ID;
    -- delete dependencies in Forums_ForumModerators
    DELETE FROM [Forums_ForumModerators] WHERE UserID=@ID;
    -- delete dependencies in Forums_ForumSubscription
    DELETE FROM [Forums_ForumSubscription] WHERE SubscriptionUserID=@ID;
    -- updates dependencies in CMS_EventLog, CMC_Document, CMS_VersionHistory and CMS_WorkflowHistory
    UPDATE [CMS_Document] SET DocumentCreatedByUserID=NULL WHERE DocumentCreatedByUserID=@ID;
    UPDATE [CMS_Document] SET DocumentCheckedOutByUserID=NULL WHERE DocumentCheckedOutByUserID=@ID;
    UPDATE [CMS_Document] SET DocumentModifiedByUserID=NULL WHERE DocumentModifiedByUserID=@ID;
    UPDATE [CMS_EventLog] SET UserID=NULL WHERE UserID=@ID
    UPDATE CMS_VersionHistory SET ModifiedByUserID=NULL WHERE ModifiedByUserID=@ID;
    UPDATE CMS_WorkflowHistory SET ApprovedByUserID=NULL WHERE ApprovedByUserID=@ID;
    -- remove dependencies in NodeOwner
    UPDATE [CMS_Tree] SET NodeOwner=NULL WHERE NodeOwner=@ID;
    -- remove dependencies in CMS_ACLItem
    DELETE FROM CMS_ACLItem WHERE UserID = @ID;
    UPDATE CMS_ACLItem SET LastModifiedByUserID=NULL WHERE LastModifiedByUserID=@ID;
    -- update dependencies in COM_Customer, COM_OrderStatusUser, COM_ShoppingCart
    UPDATE COM_Customer SET CustomerUserID=NULL WHERE CustomerUserID=@ID;
    UPDATE COM_OrderStatusUser SET ChangedByUserID=NULL WHERE ChangedByUserID=@ID;
    UPDATE COM_ShoppingCart SET ShoppingCartUserID=NULL WHERE ShoppingCartUserID=@ID;
    -- remove dependencies in COM_UserDepartment
    DELETE FROM COM_UserDepartment WHERE UserID=@ID;
    -- remove dependencies in [COM_Wishlist]
    DELETE FROM [COM_Wishlist] WHERE UserID=@ID;
    -- set null to media file FKs
    UPDATE Media_File SET FileCreatedByUserID=NULL WHERE FileCreatedByUserID=@ID;
    UPDATE Media_File SET FileModifiedByUserID=NULL WHERE FileModifiedByUserID=@ID;
    -- set null to saved reports
    UPDATE Reporting_SavedReport SET SavedReportCreatedByUserID = NULL WHERE SavedReportCreatedByUserID=@ID
    -- set null to checkouted templates, layouts and css styles
    UPDATE CMS_PageTemplate SET PageTemplateLayoutCheckedOutByUserID = NULL WHERE PageTemplateLayoutCheckedOutByUserID = @ID;
    UPDATE CMS_Layout SET LayoutCheckedOutByUserID = NULL WHERE LayoutCheckedOutByUserID=@ID;
    UPDATE CMS_CssStyleSheet SET StylesheetCheckedOutByUserID = NULL WHERE StylesheetCheckedOutByUserID=@ID;
    -- Blog_Comment - set CommentUserID a CommentApprovedByUserID to null
    UPDATE Blog_Comment SET CommentUserID = NULL WHERE CommentUserID=@ID;
    UPDATE Blog_Comment SET CommentApprovedByUserID = NULL WHERE CommentApprovedByUserID=@ID;
    UPDATE Blog_PostSubscription SET SubscriptionUserID = NULL WHERE SubscriptionUserID=@ID;
    -- Messaging_Message - set MessageSenderUserID to null and MessageSenderDeleted to true
    UPDATE Messaging_Message SET MessageSenderUserID = NULL, MessageSenderDeleted=1 WHERE MessageSenderUserID=@ID;
    UPDATE Messaging_Message SET MessageRecipientUserID = NULL, MessageRecipientDeleted=1 WHERE MessageRecipientUserID=@ID;
    DELETE FROM Messaging_Message WHERE MessageRecipientDeleted=1 AND MessageSenderDeleted=1;
    -- ForumsPost
    UPDATE Forums_ForumPost SET PostUserID = NULL WHERE PostUserID = @ID;
    UPDATE Forums_ForumPost SET PostApprovedByUserID = NULL WHERE PostApprovedByUserID = @ID;
    -- Forum user favorites
    DELETE FROM [Forums_UserFavorites] WHERE UserID = @ID;
    -- Export history
    UPDATE Export_History SET ExportUserID = NULL
    -- Groups
    UPDATE [Community_Group] SET GroupCreatedByUserID = NULL WHERE GroupCreatedByUserID = @ID;
    UPDATE [Community_Group] SET GroupApprovedByUserID = NULL WHERE GroupApprovedByUserID = @ID;
    DELETE FROM [Community_GroupMember] WHERE MemberUserID = @ID;
    UPDATE [Community_GroupMember] SET MemberApprovedByUserID = NULL WHERE MemberApprovedByUserID = @ID;
    UPDATE [Community_GroupMember] SET MemberInvitedByUserID = NULL WHERE MemberInvitedByUserID = @ID;
    -- Notifications
    DELETE FROM Notification_Subscription WHERE SubscriptionUserID = @ID;
    -- Message boards
    DELETE Board_Moderator WHERE UserID = @ID;
    UPDATE Board_Message SET MessageUserID = NULL WHERE MessageUserID = @ID;
    UPDATE Board_Message SET MessageApprovedByUserID = NULL WHERE MessageApprovedByUserID = @ID;
    DELETE Board_Moderator WHERE UserID = @ID;
    -- User message boards
    DELETE FROM Board_Message WHERE MessageBoardID IN ( SELECT BoardID FROM Board_Board WHERE BoardUserID = @ID );
    DELETE FROM Board_Moderator WHERE BoardID IN ( SELECT BoardID FROM Board_Board WHERE BoardUserID = @ID );
    DELETE FROM Board_Role WHERE BoardID IN ( SELECT BoardID FROM Board_Board WHERE BoardUserID = @ID );        
	DELETE FROM Board_Subscription WHERE SubscriptionUserID = @ID; -- delete users subscriptions   
    DELETE FROM Board_Subscription WHERE SubscriptionBoardID IN (SELECT BoardID FROM Board_Board WHERE BoardUserID = @ID); --delete subscriptions on users boards
    DELETE FROM Board_Board WHERE BoardUserID = @ID;
    -- Abuse report
    UPDATE CMS_AbuseReport SET ReportUserID = NULL WHERE ReportUserID = @ID;
    -- Contact list
    DELETE Messaging_ContactList WHERE ContactListUserID = @ID OR ContactListContactUserID = @ID;
    -- Ignore list
    DELETE Messaging_IgnoreList WHERE IgnoreListUserID = @ID OR IgnoreListIgnoredUserID = @ID;
    -- Friends
    DELETE Community_Friend WHERE FriendRequestedUserID = @ID OR FriendUserID = @ID OR FriendApprovedBy = @ID OR FriendRejectedBy = @ID;
    -- Categories
    DELETE CMS_DocumentCategory WHERE CategoryID IN ( SELECT CategoryID FROM CMS_Category WHERE CategoryUserID = @ID );
    DELETE CMS_Category WHERE CategoryUserID = @ID;
    -- Delete user sessions
    DELETE FROM CMS_Session WHERE SessionUserID = @ID;
    -- Invitations
    DELETE FROM [Community_Invitation] WHERE InvitedUserID = @ID OR InvitedByUserID = @ID;
    -- Activated by user id
    UPDATE [CMS_UserSettings] SET UserActivatedByUserID = NULL WHERE UserActivatedByUserID = @ID;
    --Widgets
    DELETE FROM CMS_Personalization WHERE PersonalizationUserID = @ID;
    --OpenIDUser
    DELETE FROM CMS_OpenIDUser WHERE UserID = @ID;
    --Newsletters
    DELETE FROM [Newsletter_SubscriberNewsletter] WHERE [SubscriberID] IN (SELECT SubscriberID FROM Newsletter_Subscriber WHERE SubscriberType LIKE 'cms.user' AND SubscriberRelatedID = @ID);
    DELETE FROM [Newsletter_Emails] WHERE EmailSubscriberID IN (SELECT SubscriberID FROM Newsletter_Subscriber WHERE SubscriberType LIKE 'cms.user' AND SubscriberRelatedID = @ID);
    DELETE FROM [Newsletter_Subscriber] WHERE SubscriberType LIKE 'cms.user' AND SubscriberRelatedID = @ID;
    -- Project management
	UPDATE [PM_Project] SET ProjectOwner = NULL WHERE ProjectOwner = @ID;
	UPDATE [PM_Project] SET ProjectCreatedByID = NULL WHERE ProjectCreatedByID = @ID;
	UPDATE [PM_ProjectTask] SET ProjectTaskOwnerID = NULL WHERE ProjectTaskOwnerID = @ID;
	UPDATE [PM_ProjectTask] SET ProjectTaskAssignedToUserID = NULL WHERE ProjectTaskAssignedToUserID = @ID;
	UPDATE [PM_ProjectTask] SET ProjectTaskCreatedByID = NULL WHERE ProjectTaskCreatedByID = @ID;
    
    COMMIT TRANSACTION;
END
GO

/* ----------------------------------------------------------------------------*/
/* This SQL command must be at the end and must contain current hotfix version */
/* ----------------------------------------------------------------------------*/
UPDATE [CMS_SettingsKey] SET KeyValue = '2' WHERE KeyName = N'CMSHotfixVersion'
GO




